==> haskell-doctest-lib-0.1.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-lib
version:              0.1.1
visibility:           public
id:                   doctest-lib-0.1.1-1629psDl3zADIJbWNrTmG7
key:                  doctest-lib-0.1.1-1629psDl3zADIJbWNrTmG7
license:              MIT
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:
    Henning Thielemann <haskell@henning-thielemann.de>, Simon Hengel <sol@typeful.net>

homepage:             https://hub.darcs.net/thielema/doctest-lib/
synopsis:             Parts of doctest exposed as library
description:
    Parts of doctest exposed as library.
    For use with the doctest-extract utility.

category:             Testing
abi:                  b0768c95fa6ff373792560a76c4a5817
exposed:              True
exposed-modules:
    Test.DocTest.Base Test.DocTest.Location Test.DocTest.Parse

import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-lib-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-lib-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-lib
hs-libraries:         HSdoctest-lib-0.1.1-1629psDl3zADIJbWNrTmG7
depends:
    base-4.15.1.0 utility-ht-0.0.17.1-AwzzxlMNELkBs8zuLPQyOf

haddock-interfaces:   /usr/share/doc/haskell-doctest-lib/html/doctest-lib.haddock
haddock-html:         /usr/share/doc/haskell-doctest-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-lib-0.1.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-lib
version:              0.1.1
visibility:           public
id:                   doctest-lib-0.1.1-24WV7OVrx7h9IaQzgZrxG9
key:                  doctest-lib-0.1.1-24WV7OVrx7h9IaQzgZrxG9
license:              MIT
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:
    Henning Thielemann <haskell@henning-thielemann.de>, Simon Hengel <sol@typeful.net>

homepage:             https://hub.darcs.net/thielema/doctest-lib/
synopsis:             Parts of doctest exposed as library
description:
    Parts of doctest exposed as library.
    For use with the doctest-extract utility.

category:             Testing
abi:                  655dadaad31e26ad84d89173fc9ec04c
exposed:              True
exposed-modules:
    Test.DocTest.Base Test.DocTest.Location Test.DocTest.Parse

import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-lib-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-lib-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-lib
hs-libraries:         HSdoctest-lib-0.1.1-24WV7OVrx7h9IaQzgZrxG9
depends:
    base-4.16.4.0 utility-ht-0.0.17.1-5iBQ3TYzqb7J5p4ffcIkxT

haddock-interfaces:   /usr/share/doc/haskell-doctest-lib/html/doctest-lib.haddock
haddock-html:         /usr/share/doc/haskell-doctest-lib/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
